@@ -88,6 +88,8 @@ use std::fmt;
 pub struct DemangleOptions {
     /// Do not display function arguments.
     pub no_params: bool,
+    /// Do not display the function return type.
+    pub no_return_type: bool,
 }
 
 /// A `Symbol` which owns the underlying storage for the mangled name.
@@ -247,6 +249,8 @@ pub enum DemangleNodeType {
     DataMemberPrefix,
     /// Entering a <nested-name> production
     NestedName,
+    /// Entering a <special-name> production that is a vtable.
+    VirtualTable,
 }
 
 /// Sink for demangled text that reports syntactic structure.
